@@ -36,7 +36,7 @@
 #include <fcntl.h>
 #include <linux/videodev2.h>
 #include <string.h>
-#include <errno.h>
+//#include <errno.h>
 #include <assert.h>
 #include <sys/statfs.h>
 #include <libavformat/avformat.h>
@@ -53,7 +53,7 @@
 #include <locale.h>
 #include <libintl.h>
 
-#include "config.h"
+#include "cameraconfig.h"
 #include "gviewencoder.h"
 #include "encoder.h"
 #include "stream_io.h"
@@ -61,7 +61,7 @@
 #include "avi.h"
 #include "mp4.h"
 #include "gview.h"
-
+#include "load_libs.h"
 
 extern int verbosity;
 
@@ -357,7 +357,7 @@ void encoder_muxer_init(encoder_context_t *encoder_ctx, const char *filename)
                 mp4_ctx,
                 video_codec_data,
                 mp4_video_stream);
-            int ret = avcodec_parameters_from_context(mp4_video_stream->st->codecpar, mp4_video_stream->enc);
+            int ret = getLoadLibsInstance()->m_avcodec_parameters_from_context(mp4_video_stream->st->codecpar, mp4_video_stream->enc);
                 if (ret < 0) {
                     fprintf(stderr, "Could not copy the stream parameters\n");
                     exit(1);
@@ -375,9 +375,9 @@ void encoder_muxer_init(encoder_context_t *encoder_ctx, const char *filename)
                     mp4_audio_stream);
                 }
                  if(!video_codec_data->private_options)
-                    av_dict_copy(opt,video_codec_data->private_options, AV_DICT_DONT_OVERWRITE);
+                    getAvutil()->m_av_dict_copy(opt,video_codec_data->private_options, AV_DICT_DONT_OVERWRITE);
 
-                 int ret = avcodec_parameters_from_context(mp4_audio_stream->st->codecpar, mp4_audio_stream->enc);
+                 int ret = getLoadLibsInstance()->m_avcodec_parameters_from_context(mp4_audio_stream->st->codecpar, mp4_audio_stream->enc);
                      if (ret < 0) {
                          fprintf(stderr, "Could not copy the stream parameters\n");
                          exit(1);
@@ -386,16 +386,16 @@ void encoder_muxer_init(encoder_context_t *encoder_ctx, const char *filename)
                     //av_dict_copy(opt,video_codec_data->private_options, AV_DICT_DONT_OVERWRITE);
             }
 
-            ret = avio_open(&mp4_ctx->pb, filename, AVIO_FLAG_WRITE);
+            ret = getAvformat()->m_avio_open(&mp4_ctx->pb, filename, AVIO_FLAG_WRITE);
             if (ret < 0) {
-                fprintf(stderr, "Could not open '%s': %s\n", filename,
-                        av_err2str(ret));
+                //fprintf(stderr, "Could not open '%s': %s\n", filename,
+                        //av_err2str(ret));
             }
-            ret= avformat_write_header(mp4_ctx, opt);
+            ret= getAvformat()->m_avformat_write_header(mp4_ctx, opt);
             if(ret < 0)
             {
-                fprintf(stderr, "Error occurred when opening output file: %s\n",
-                                av_err2str(ret));
+//                fprintf(stderr, "Error occurred when opening output file: %s\n",
+//                                av_err2str(ret));
             }
             break;
 
@@ -511,19 +511,19 @@ void encoder_muxer_close(encoder_context_t *encoder_ctx)
         case ENCODER_MUX_MP4:
             if(mp4_ctx)
             {
-                av_write_trailer(mp4_ctx);
-                avio_closep(&mp4_ctx->pb);
+                getAvformat()->m_av_write_trailer(mp4_ctx);
+                getAvformat()->m_avio_closep(&mp4_ctx->pb);
 
 //                if(!!mp4_video_stream->enc)
 //                    avcodec_free_context(&mp4_video_stream->enc);
                 if(!!mp4_video_stream->frame)
-                    av_frame_free(&mp4_video_stream->frame);
+                    getAvutil()->m_av_frame_free(&mp4_video_stream->frame);
                 if(!!mp4_video_stream->tmp_frame)
-                    av_frame_free(&mp4_video_stream->tmp_frame);
+                    getAvutil()->m_av_frame_free(&mp4_video_stream->tmp_frame);
                 if(!!mp4_video_stream->sws_ctx)
-                    sws_freeContext(mp4_video_stream->sws_ctx);
+                    getLoadLibsInstance()->m_sws_freeContext(mp4_video_stream->sws_ctx);
                 if(!!mp4_video_stream->swr_ctx)
-                    swr_free(&mp4_video_stream->swr_ctx);
+                    getLoadLibsInstance()->m_swr_free(&mp4_video_stream->swr_ctx);
                 if(!!mp4_video_stream)
                 {
                     free(mp4_video_stream);
@@ -533,13 +533,13 @@ void encoder_muxer_close(encoder_context_t *encoder_ctx)
                 //if(!!mp4_audio_stream->enc)
                     //avcodec_free_context(&mp4_audio_stream->enc);
                 if(!!mp4_audio_stream->frame)
-                    av_frame_free(&mp4_audio_stream->frame);
+                    getAvutil()->m_av_frame_free(&mp4_audio_stream->frame);
                 if(!!mp4_audio_stream->tmp_frame)
-                    av_frame_free(&mp4_audio_stream->tmp_frame);
+                    getAvutil()->m_av_frame_free(&mp4_audio_stream->tmp_frame);
                 if(!!mp4_audio_stream->sws_ctx)
-                    sws_freeContext(mp4_audio_stream->sws_ctx);
+                    getLoadLibsInstance()->m_sws_freeContext(mp4_audio_stream->sws_ctx);
                 if(!!mp4_audio_stream->swr_ctx)
-                    swr_free(&mp4_audio_stream->swr_ctx);
+                    getLoadLibsInstance()->m_swr_free(&mp4_audio_stream->swr_ctx);
                 if(!!mp4_audio_stream)
                 {
                     free(mp4_audio_stream);
