@@ -42,10 +42,12 @@
 #include "frame_decoder.h"
 #include "jpeg_decoder.h"
 #include "gview.h"
-#include "config.h"
+#include "cameraconfig.h"
 
 //LMH0613++
 #include <libavutil/imgutils.h>
+
+#include "load_libs.h"
 extern int verbosity;
 
 /* default Huffman table*/
@@ -1373,16 +1375,16 @@ typedef struct _codec_data_t
 int jpeg_init_decoder(int width, int height)
 {
 #if !LIBAVCODEC_VER_AT_LEAST(53,34)
-	avcodec_init();
+    getLoadLibsInstance()->m_avcodec_init();
 #endif
 #if !LIBAVCODEC_VER_AT_LEAST(58,9)
 	/*
 	 * register all the codecs (we can also register only the codec
 	 * we wish to have smaller code)
 	 */
-	avcodec_register_all();
+    getLoadLibsInstance()->m_avcodec_register_all();
 #endif
-	av_log_set_level(AV_LOG_PANIC);
+    getAvutil()->m_av_log_set_level(AV_LOG_PANIC);
 
 	if(jpeg_ctx != NULL)
 		jpeg_close_decoder();
@@ -1401,7 +1403,7 @@ int jpeg_init_decoder(int width, int height)
 		exit(-1);
 	}
 
-	codec_data->codec = avcodec_find_decoder(AV_CODEC_ID_MJPEG);
+    codec_data->codec = getLoadLibsInstance()->m_avcodec_find_decoder(AV_CODEC_ID_MJPEG);
 	if(!codec_data->codec)
 	{
 		fprintf(stderr, "V4L2_CORE: (mjpeg decoder) codec not found\n");
@@ -1412,11 +1414,11 @@ int jpeg_init_decoder(int width, int height)
 	}
 
 #if LIBAVCODEC_VER_AT_LEAST(53,6)
-	codec_data->context = avcodec_alloc_context3(codec_data->codec);
-	avcodec_get_context_defaults3 (codec_data->context, codec_data->codec);
+    codec_data->context = getLoadLibsInstance()->m_avcodec_alloc_context3(codec_data->codec);
+    getLoadLibsInstance()->m_avcodec_get_context_defaults3 (codec_data->context, codec_data->codec);
 #else
-	codec_data->context = avcodec_alloc_context();
-	avcodec_get_context_defaults(codec_data->context);
+    codec_data->context = getLoadLibsInstance()->m_avcodec_alloc_context();
+    getLoadLibsInstance()->m_avcodec_get_context_defaults(codec_data->context);
 #endif
 	if(codec_data->context == NULL)
 	{
@@ -1430,13 +1432,13 @@ int jpeg_init_decoder(int width, int height)
 	//jpeg_ctx->context->dsp_mask = (FF_MM_MMX | FF_MM_MMXEXT | FF_MM_SSE);
 
 #if LIBAVCODEC_VER_AT_LEAST(53,6)
-	if (avcodec_open2(codec_data->context, codec_data->codec, NULL) < 0)
+    if (getLoadLibsInstance()->m_avcodec_open2(codec_data->context, codec_data->codec, NULL) < 0)
 #else
-	if (avcodec_open(codec_data->context, codec_data->codec) < 0)
+    if (getLoadLibsInstance()->m_avcodec_open(codec_data->context, codec_data->codec) < 0)
 #endif
 	{
 		fprintf(stderr, "V4L2_CORE: (mjpeg decoder) couldn't open codec\n");
-		avcodec_close(codec_data->context);
+        getLoadLibsInstance()->m_avcodec_close(codec_data->context);
 		free(codec_data->context);
 		free(codec_data);
 		free(jpeg_ctx);
@@ -1445,11 +1447,11 @@ int jpeg_init_decoder(int width, int height)
 	}
 
 #if LIBAVCODEC_VER_AT_LEAST(55,28)
-	codec_data->picture = av_frame_alloc();
-	av_frame_unref(codec_data->picture);
+    codec_data->picture = getAvutil()->m_av_frame_alloc();
+    getAvutil()->m_av_frame_unref(codec_data->picture);
 #else
-	codec_data->picture = avcodec_alloc_frame();
-	avcodec_get_frame_defaults(codec_data->picture);
+    codec_data->picture = getLoadLibsInstance()->m_avcodec_alloc_frame();
+    getLoadLibsInstance()->m_avcodec_get_frame_defaults(codec_data->picture);
 #endif
 
 	/*alloc temp buffer*/
@@ -1460,7 +1462,7 @@ int jpeg_init_decoder(int width, int height)
 		exit(-1);
 	}
 #if LIBAVUTIL_VER_AT_LEAST(54,6)
-	jpeg_ctx->pic_size = av_image_get_buffer_size(codec_data->context->pix_fmt, width, height, 1);
+    jpeg_ctx->pic_size = getAvutil()->m_av_image_get_buffer_size(codec_data->context->pix_fmt, width, height, 1);
 #else
 	jpeg_ctx->pic_size = avpicture_get_size(codec_data->context->pix_fmt, width, height);
 #endif
@@ -1494,7 +1496,7 @@ int jpeg_decode(uint8_t *out_buf, uint8_t *in_buf, int size)
 
 	AVPacket avpkt;
 
-	av_init_packet(&avpkt);
+    getLoadLibsInstance()->m_av_init_packet(&avpkt);
 
 	avpkt.size = size;
 	avpkt.data = in_buf;
@@ -1513,17 +1515,30 @@ int jpeg_decode(uint8_t *out_buf, uint8_t *in_buf, int size)
 	if(got_frame)
 	{
 #if LIBAVUTIL_VER_AT_LEAST(54,6)
-        av_image_copy_to_buffer(jpeg_ctx->tmp_frame, jpeg_ctx->pic_size,
+        getAvutil()->m_av_image_copy_to_buffer(jpeg_ctx->tmp_frame, jpeg_ctx->pic_size,
                              (const uint8_t * const*) codec_data->picture->data, codec_data->picture->linesize,
                              codec_data->context->pix_fmt, jpeg_ctx->width, jpeg_ctx->height, 1);
 #else
 		avpicture_layout((AVPicture *) codec_data->picture, codec_data->context->pix_fmt,
 			jpeg_ctx->width, jpeg_ctx->height, jpeg_ctx->tmp_frame, jpeg_ctx->pic_size);
 #endif
-		/* libavcodec output is in yuv422p */
-        yuv422p_to_yu12(out_buf, jpeg_ctx->tmp_frame, jpeg_ctx->width, jpeg_ctx->height);
 
-		return jpeg_ctx->pic_size;
+        if (codec_data->context->pix_fmt == AV_PIX_FMT_YUVJ422P) {
+            /* libavcodec output is in yuvj422p */
+
+            yuv422p_to_yu12(out_buf, jpeg_ctx->tmp_frame, jpeg_ctx->width, jpeg_ctx->height);
+            return jpeg_ctx->pic_size;
+        } else if (codec_data->context->pix_fmt == AV_PIX_FMT_YUVJ420P) {
+            /* libavcodec output is in yuvj420p */
+
+            if (jpeg_ctx->pic_size > (size_t)(jpeg_ctx->width * jpeg_ctx->height * 3 / 2))
+                jpeg_ctx->pic_size  = (size_t)(jpeg_ctx->width * jpeg_ctx->height * 3 / 2);
+
+            memcpy(out_buf, jpeg_ctx->tmp_frame, jpeg_ctx->pic_size);
+
+            return jpeg_ctx->pic_size;
+        }else
+            return 0;
 	}
 	else
 		return 0;
@@ -1547,15 +1562,15 @@ void jpeg_close_decoder()
 
 	codec_data_t *codec_data = (codec_data_t *) jpeg_ctx->codec_data;
 
-	avcodec_close(codec_data->context);
+    getLoadLibsInstance()->m_avcodec_close(codec_data->context);
 
 	free(codec_data->context);
 
 #if LIBAVCODEC_VER_AT_LEAST(55,28)
-	av_frame_free(&codec_data->picture);
+    getAvutil()->m_av_frame_free(&codec_data->picture);
 #else
 	#if LIBAVCODEC_VER_AT_LEAST(54,28)
-			avcodec_free_frame(&codec_data->picture);
+            getLoadLibsInstance()->m_avcodec_free_frame(&codec_data->picture);
 	#else
 			av_freep(&codec_data->picture);
 	#endif
