@@ -3,7 +3,7 @@
 *
 * Author:     shicetu <shicetu@uniontech.com>
 *             hujianbo <hujianbo@uniontech.com>
-* Maintainer:  shicetu <shicetu@uniontech.com>
+* Maintainer: shicetu <shicetu@uniontech.com>
 *             hujianbo <hujianbo@uniontech.com>
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -23,25 +23,34 @@
 
 #include <DDialog>
 #include <DWidget>
-#include <QVBoxLayout>
-#include <QHBoxLayout>
+#include <DLabel>
 #include <DLineEdit>
 #include <DPushButton>
 #include <DSuggestButton>
-#include <DLabel>
+
+#include <QVBoxLayout>
+#include <QHBoxLayout>
+
 DWIDGET_USE_NAMESPACE
 
 typedef DLabel QLbtoDLabel;
+
+/**
+* @brief CloseDialog　关闭对话框
+*/
 class CloseDialog : public DDialog
 {
     Q_OBJECT
+    
 public:
-    CloseDialog(QWidget *parent = nullptr, QString strText = "", QString btnName1 = tr("Cancel"), QString btnName2 = tr("Close"));
+    CloseDialog(QWidget *parent = nullptr, QString strText = "");
 
 private:
-    QVBoxLayout *m_vlayout;
-    DWidget *widet;
-    QLbtoDLabel *labtitle;
+    const QString m_leftNamebtn;
+    const QString m_rightNamebtn;
+    QVBoxLayout  *m_vlayout;
+    DWidget      *m_widget;
+    QLbtoDLabel  *m_labtitle;
 };
 
 #endif // CLOSEDIALOG_H
