@@ -70,8 +70,8 @@ extern int encodeenv;
 
 using namespace dc;
 
-const int CMainWindow::minWindowWidth = 800;
-const int CMainWindow::minWindowHeight = 600;
+const int CMainWindow::minWindowWidth = 680;
+const int CMainWindow::minWindowHeight = 510;
 
 const int rightOffset = 10;
 const int SwitchcameraDiam = 40; //切换摄像头直径
@@ -84,6 +84,8 @@ const int labelCameraNameHeight = 26;
 const int labelFilterNameWidth = 150;
 const int labelFilterNameHeight = 26;
 const int pathEditWidth = 285;
+const int defaultWindowWidth = 800;
+const int defaultWindowHeight = 600;
 
 static void workaround_updateStyle(QWidget *parent, const QString &theme)
 {
@@ -1792,7 +1794,7 @@ void CMainWindow::initUI()
     m_videoPre->setInterval(nDelayTime);
     m_videoPre->setContinuous(nContinuous);
     m_videoPre->setMaxRecTime(dc::Settings::get().getOption("photosetting.maxRecordTime.maxRecordTime").toInt());
-    resize(minWindowWidth, minWindowHeight);
+    resize(defaultWindowWidth, defaultWindowHeight);
 
     m_takePhotoSettingArea->setDelayTime(nDelayTime);
     m_takePhotoSettingArea->setFlashlight(dc::Settings::get().getOption("photosetting.Flashlight.Flashlight").toBool());
@@ -2047,8 +2049,10 @@ void CMainWindow::resizeEvent(QResizeEvent *event)
     m_pTitlebar->titlebar()->setFixedWidth(this->size().width());
 
     QTimer::singleShot(1, this, [ = ] {
-        if (nullptr != m_takePhotoSettingArea)
+        if (nullptr != m_takePhotoSettingArea) {
             m_takePhotoSettingArea->moveToParentLeft();
+            m_takePhotoSettingArea->resizeScrollHeight(height() - minWindowHeight);
+        }
     });
 }
 
