@@ -25,6 +25,7 @@
 #include "ac-deepin-camera-define.h"
 #include "capplication.h"
 #include "photorecordbtn.h"
+#include "camera.h"
 
 #include <DBlurEffectWidget>
 
@@ -74,9 +75,14 @@ void QGraphicsViewEx::mouseMoveEvent(QMouseEvent *e)
 videowidget::videowidget(DWidget *parent)
     : DWidget(parent),
       m_imgPrcThread(nullptr),
+      m_audPrcThread(nullptr),
       m_nMaxRecTime(60), //默认60小时
       m_openglwidget(nullptr),
-      m_gridlinewidget(nullptr)
+      m_gridlinewidget(nullptr),
+      m_GridType(Grid_None),
+      m_videoWriter(nullptr),
+      m_filterType(filter_Normal),
+      m_exposure(0)
 {
 #ifndef __mips__
     if (!get_wayland_status()) {
@@ -94,7 +100,7 @@ videowidget::videowidget(DWidget *parent)
     m_recordingTimer = new QTimer(this);
     m_pNormalView = new QGraphicsViewEx(this);
     m_gridlinewidget = new GridLineWidget(this);
-    m_gridlinewidget->setGridType(Grid_Thirds);
+    m_gridlinewidget->setGridType(Grid_None);
     QDesktopWidget *desktopWidget = QApplication::desktop();
     //获取设备屏幕大小
     QRect screenRect = desktopWidget->screenGeometry();
@@ -116,7 +122,7 @@ videowidget::videowidget(DWidget *parent)
     m_pNormalScene = new QGraphicsScene();
     // 画布网格线图元
     m_pGridLineItem = new GridLineItem;
-    m_pGridLineItem->setGridType(Grid_Matts);
+    m_pGridLineItem->setGridType(Grid_None);
     m_pGridLineItem->setZValue(1);
     // 画布svg图标图元
     m_pSvgItem = new QGraphicsSvgItem;
@@ -256,6 +262,14 @@ void videowidget::delayInit()
     connect(m_imgPrcThread, SIGNAL(sigReflushSnapshotLabel()),
             this, SIGNAL(reflushSnapshotLabel()));
 
+    connect(m_imgPrcThread, SIGNAL(sigRecordFrame(uchar*, uint)),
+            this, SLOT(onRecordFrame(uchar*, uint)));
+
+    m_audPrcThread = new AudioProcessingThread;
+    m_audPrcThread->setParent(this);
+    m_audPrcThread->setObjectName("AudioThread");
+    connect(m_audPrcThread, SIGNAL(sendAudioProcessing(uchar*, uint)), this, SLOT(onRecordAudio(uchar*, uint)));
+
     QPalette pltFlashLabel = m_flashLabel->palette();
     pltFlashLabel.setColor(QPalette::Window, QColor(Qt::white));
     m_flashLabel->setPalette(pltFlashLabel);
@@ -401,7 +415,7 @@ void videowidget::ReceiveOpenGLstatus(bool result)
 
         m_pNormalScene->update();
 
-        if (get_encoder_status() == 0 && getCapStatus())
+        if (get_encoder_status() == 0 && getCapStatus() && DataManager::instance()->encodeEnv() == FFmpeg_Env)
             onEndBtnClicked();
 
         // 画布窗口等比例缩放画面
@@ -435,7 +449,7 @@ void videowidget::ReceiveMajorImage(QImage *image, int result)
     if (!image->isNull()) {
         switch (result) {
         case 0:     //Success
-            m_imgPrcThread->m_rwMtxImg.lock();
+//            m_imgPrcThread->m_rwMtxImg.lock();
             m_pNormalView->show();
             m_pCamErrItem->hide();
             m_pSvgItem->hide();
@@ -464,10 +478,15 @@ void videowidget::ReceiveMajorImage(QImage *image, int result)
 
                 m_pNormalScene->setSceneRect(m_framePixmap.rect());
                 m_pNormalItem->setPixmap(m_framePixmap);
-                m_imgPrcThread->m_rwMtxImg.unlock();
+//                m_imgPrcThread->m_rwMtxImg.unlock();
 
-                if (get_encoder_status() == 0 && getCapStatus() == true)
-                    onEndBtnClicked();
+                if (DataManager::instance()->encodeEnv() == FFmpeg_Env) {
+                    if (get_encoder_status() == 0 && getCapStatus() == true)
+                        onEndBtnClicked();
+                } else if (DataManager::instance()->encodeEnv() == QCamera_Env) {
+                    if (Camera::instance()->getRecoderState() == 0 && getCapStatus() == true && !Camera::instance()->isReadyRecord())
+                        onEndBtnClicked();
+                }
 
                 malloc_trim(0);
             }
@@ -615,11 +634,14 @@ void videowidget::showCountdown()
         m_dLabel->hide();
         if (g_Enum_Camera_State == VIDEO) {
             if (!getCapStatus()) {
-                /*m_bActive录制状态判断
-                *false：非录制状态
-                *true：录制状态
-                */
-                startTakeVideo();
+                if (DataManager::instance()->encodeEnv() != QCamera_Env) {
+                    /*m_bActive录制状态判断
+                    *false：非录制状态
+                    *true：录制状态
+                    */
+                    startTakeVideo();
+                } else
+                    startCaptureVideo();
             }
 
             showCountDownLabel(g_Enum_Camera_State);
@@ -643,6 +665,8 @@ void videowidget::showCountdown()
                     m_pNormalView->hide();
                 if (m_openglwidget)
                     m_openglwidget->hide();
+                if (m_gridlinewidget)
+                    m_gridlinewidget->hide();
             }
 
             //发送就结束信号处理按钮状态
@@ -650,7 +674,7 @@ void videowidget::showCountdown()
             emit updatePhotoState(CMainWindow::Photoing);
 
             if (QDir(m_savePicFolder).exists() == false) {
-                QString strDefaultPath = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation) + QDir::separator() + QObject::tr("Camera");
+                QString strDefaultPath = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation) + QDir::separator() + "Camera";
                 if (QDir(strDefaultPath).exists() == false) {
                     QDir dir;
                     dir.mkdir(strDefaultPath);
@@ -738,12 +762,19 @@ void videowidget::showCountdown()
 void videowidget::showRecTime()
 {
     //获取写video的时间
-    m_nCount = static_cast<int>(get_video_time_capture());
+    if (DataManager::instance()->encodeEnv() == FFmpeg_Env) {
+        m_nCount = static_cast<int>(get_video_time_capture());
 
-    //过滤不正常的时间
-    if (m_nCount <= 3) {
-        qWarning() << "error time" << m_nCount;
-        return;
+        //过滤不正常的时间
+        if (m_nCount <= 3) {
+            qWarning() << "error time" << m_nCount;
+            return;
+        }
+    } else if (DataManager::instance()->encodeEnv() == QCamera_Env) {
+        m_nCount = Camera::instance()->getRecoderTime() / 1000;
+        m_nCount += 2;
+    } else if (DataManager::instance()->encodeEnv() == GStreamer_Env) {
+        m_nCount = m_videoWriter->getRecrodTime();
     }
 
     if (m_nCount >= m_nMaxRecTime * 60 * 60)//最大录制时长，平板与主线保持一致
@@ -798,7 +829,7 @@ void videowidget::flash()
 
 #ifndef __mips__
     if (!get_wayland_status())
-        if (m_openglwidget->isVisible() == false)
+        if (!m_openglwidget->isVisible() && filter_Normal == m_filterType && 0 == m_exposure)
             m_openglwidget->show();
 
 #endif
@@ -828,15 +859,24 @@ void videowidget::slotresolutionchanged(const QString &resolution)
     int newwidth = ResStr[0].toInt();//新的宽度
     int newheight = ResStr[1].toInt();//新的高度
 
-    int nWidth = v4l2core_get_frame_width(get_v4l2_device_handler());
-    int nHeight = v4l2core_get_frame_height(get_v4l2_device_handler());
+    if (DataManager::instance()->encodeEnv() == QCamera_Env) {
+        QSize resolution = Camera::instance()->getCameraResolution();
+        if (resolution.width() != newwidth || resolution.height() != newheight) {
+            QSize size(newwidth, newheight);
+            Camera::instance()->setCameraResolution(size);
+        }
 
-    if (newwidth != nWidth || newheight != nHeight) {
-        //设置刷新率
-        v4l2core_define_fps(get_v4l2_device_handler(), 1, 30);
-        //设置新的分辨率
-        v4l2core_prepare_new_resolution(get_v4l2_device_handler(), newwidth, newheight);
-        request_format_update(1);
+    } else {
+        int nWidth = v4l2core_get_frame_width(get_v4l2_device_handler());
+        int nHeight = v4l2core_get_frame_height(get_v4l2_device_handler());
+
+        if (newwidth != nWidth || newheight != nHeight) {
+            //设置刷新率
+            v4l2core_define_fps(get_v4l2_device_handler(), 1, 30);
+            //设置新的分辨率
+            v4l2core_prepare_new_resolution(get_v4l2_device_handler(), newwidth, newheight);
+            request_format_update(1);
+        }
     }
 
 }
@@ -846,6 +886,18 @@ void videowidget::slotGridTypeChanged(int type)
     setGridType(static_cast<GridType>(type));
 }
 
+void videowidget::onRecordFrame(uchar *rgb, uint size)
+{
+    if (m_videoWriter)
+        m_videoWriter->writeFrame(rgb, size);
+}
+
+void videowidget::onRecordAudio(uchar *data, uint size)
+{
+    if (m_videoWriter)
+        m_videoWriter->writeAudio(data, size);
+}
+
 void videowidget::onEndBtnClicked()
 {
     if (m_countTimer->isActive())
@@ -854,10 +906,10 @@ void videowidget::onEndBtnClicked()
     if (m_recordingTimer->isActive())
         m_recordingTimer->stop();
 
-    if (m_pCamErrItem->isVisible() && (m_imgPrcThread->getStatus() == 0))
+    if (m_pCamErrItem->isVisible() && (m_imgPrcThread->getStatus() == 0) && DataManager::instance()->encodeEnv() != QCamera_Env)
         m_pCamErrItem->hide();
 
-    if (m_pSvgItem->isVisible() && (m_imgPrcThread->getStatus() == 0))
+    if (m_pSvgItem->isVisible() && (m_imgPrcThread->getStatus() == 0) && DataManager::instance()->encodeEnv() != QCamera_Env)
         m_pSvgItem->hide();
     m_dLabel->hide();
 
@@ -876,13 +928,37 @@ void videowidget::onEndBtnClicked()
     }
 
     m_recordingTimeWidget->hide();
+#ifdef __sw_64__
+    photoRecordBtn* recordBtn = nullptr;
+    CMainWindow* mainwindow = qobject_cast<CMainWindow*>(parentWidget());
+    if (mainwindow) {
+        recordBtn = mainwindow->findChild<photoRecordBtn *>(BUTTON_PICTURE_VIDEO);
+    }
+    if (recordBtn)
+        recordBtn->blockSignals(true);
+#endif
 
+    QTime time;
+    time.start();
     if (getCapStatus()) { //录制完成处理
         qDebug() << "stop takeVideo";
 
-        if (video_capture_get_save_video() == 1) {
-            set_video_time_capture(0);
-            stop_encoder_thread();
+        if (DataManager::instance()->encodeEnv() == FFmpeg_Env) {
+            if (video_capture_get_save_video() == 1) {
+                set_video_time_capture(0);
+                stop_encoder_thread();
+            }
+        } else if (DataManager::instance()->encodeEnv() == QCamera_Env) {
+            if (Camera::instance()->isRecording()) {
+                Camera::instance()->stopRecoder();
+            }
+        } else if (DataManager::instance()->encodeEnv() == GStreamer_Env) {
+            if (m_audPrcThread != nullptr)
+                m_audPrcThread->stop();
+            while (m_audPrcThread->isRunning());//等待音频线程结束
+
+            if (m_videoWriter)
+                m_videoWriter->stop();
         }
 
         setCapStatus(false);
@@ -890,6 +966,16 @@ void videowidget::onEndBtnClicked()
         emit updateBlockSystem(false);
         emit takeVdDone();
     }
+
+    qInfo() << QString("-------------------stop record cost[%1]ms..----------------\n").arg(time.elapsed());
+
+#ifdef __sw_64__
+    // 过滤停止录像编码期间的键鼠点击事件
+    qApp->processEvents();
+    if (recordBtn)
+        recordBtn->blockSignals(false);
+#endif
+
 }
 
 void videowidget::onRestartDevices()
@@ -967,7 +1053,12 @@ int videowidget::switchCamera(const char *device, const char *devName)
     if (NULL == device) {
         return -1;
     }
-    int ret = camInit(device);
+    int ret = -1;
+    if (DataManager::instance()->encodeEnv() != QCamera_Env) {
+        ret = camInit(device);
+    } else {
+        ret = 0;
+    }
     if (ret == E_OK) {
         m_imgPrcThread->init();
         m_imgPrcThread->start();
@@ -1076,7 +1167,19 @@ void videowidget::onTakeVideo() //点一次开，再点一次关
         qDebug() << "stop takeVideo";
         //向mainwindow 发送录像状态通知信号
         emit updateRecordState(photoRecordBtn::Normal);
-        stop_encoder_thread();
+        if (DataManager::instance()->encodeEnv() == FFmpeg_Env) {
+            stop_encoder_thread();
+        } else if (DataManager::instance()->encodeEnv() == QCamera_Env) {
+            Camera::instance()->stopRecoder();
+        }
+        else if (DataManager::instance()->encodeEnv() == GStreamer_Env) {
+            if (m_audPrcThread != nullptr)
+                m_audPrcThread->stop();
+            while (m_audPrcThread->isRunning());//等待音频线程结束
+
+            if (m_videoWriter)
+                m_videoWriter->stop();
+        }
         setCapStatus(false);
         reset_video_timer();
         emit updateBlockSystem(false);
@@ -1113,15 +1216,33 @@ void videowidget::forbidScrollBar(QGraphicsView *view)
 
 void videowidget::startTakeVideo()
 {
+
+#ifdef __sw_64__
+    if (video_capture_get_save_video() == 1) {
+        qInfo() << "-------------------------takeVideo reclicked..----------------------";
+        return;
+    }
+#endif
+
     QDir dir;
 
-    QString strDefaultVdPath = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation) + QDir::separator() + QObject::tr("Camera");
+    QString strDefaultVdPath = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation) + QDir::separator() + "Camera";
     if (QDir(strDefaultVdPath).exists() == false)
         dir.mkdir(strDefaultVdPath);
 
     if (getCapStatus()) {
         qDebug() << "stop takeVideo";
-        stop_encoder_thread();
+        if (DataManager::instance()->encodeEnv() == FFmpeg_Env)
+            stop_encoder_thread();
+        else if (DataManager::instance()->encodeEnv() == GStreamer_Env) {
+            if (m_audPrcThread != nullptr)
+                m_audPrcThread->stop();
+            while (m_audPrcThread->isRunning());//等待音频线程结束
+
+            if (m_videoWriter)
+                m_videoWriter->stop();
+        }
+
         setCapStatus(false);
         reset_video_timer();
         emit updateBlockSystem(false);
@@ -1133,12 +1254,77 @@ void videowidget::startTakeVideo()
             m_nFileID ++;
 
             if (QDir(m_saveVdFolder).exists() == false) {
-                m_saveVdFolder = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation) + QDir::separator() + QObject::tr("Camera");
+                m_saveVdFolder = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation) + QDir::separator() + "Camera";
             }
 
-            set_video_path(m_saveVdFolder.toStdString().c_str());
-            set_video_name(DataManager::instance()->getstrFileName().toStdString().c_str());
-            start_encoder_thread();
+            if (DataManager::instance()->encodeEnv() == FFmpeg_Env) {
+                set_video_path(m_saveVdFolder.toStdString().c_str());
+                set_video_name(DataManager::instance()->getstrFileName().toStdString().c_str());
+                start_encoder_thread();
+            } else if (DataManager::instance()->encodeEnv() == GStreamer_Env) {
+                QString recordFileName = m_saveVdFolder + "/" + DataManager::instance()->getstrFileName();
+                if (!m_videoWriter)
+                    m_videoWriter = new GstVideoWriter(recordFileName);
+                else
+                    m_videoWriter->setVideoPath(recordFileName);
+
+                m_videoWriter->start();
+                m_audPrcThread->init();
+                m_audPrcThread->start();
+            }
+            emit updateBlockSystem(true);
+            setCapStatus(true);
+            m_countTimer->stop();
+            m_countTimer->start(1000); //重新计时，否则时间与显示时间
+        } else {
+            reset_video_timer();//重置底层定时器
+            m_countTimer->stop();
+            setCapStatus(false);
+        }
+
+        m_nCount = 0;//5184000;
+        m_recordingTime->setText(QString("00:00:00"));
+        int nWidth = width();
+        int nHeight = height();
+
+        //判断倒计时阶段焦点位移到拍照/录制按钮，重新设置tab的索引
+        if (DataManager::instance()->m_tabIndex == 8)
+            DataManager::instance()->setNowTabIndex(8);
+
+        m_recordingTimeWidget->show();
+        m_recordingTimeWidget->move((nWidth - m_recordingTimeWidget->width() - 10) / 2,
+                                    nHeight - m_recordingTimeWidget->height() - 15);
+    }
+}
+
+void videowidget::startCaptureVideo()
+{
+    QDir dir;
+
+    QString strDefaultVdPath = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation) + QDir::separator() + "Camera";
+    if (QDir(strDefaultVdPath).exists() == false)
+        dir.mkdir(strDefaultVdPath);
+
+    if (getCapStatus()) {
+        qDebug() << "stop takeVideo";
+        Camera::instance()->stopRecoder();
+        setCapStatus(false);
+        reset_video_timer();
+        emit updateBlockSystem(false);
+    } else {
+        if (DataManager::instance()->getdevStatus() == CAM_CANUSE) {
+            qDebug() << "start Gstreamer takeVideo";
+            DataManager::instance()->getstrFileName() = "UOS_" + QDateTime::currentDateTime().toString("yyyyMMddHHmmss") + "_" + QString::number(m_nFileID);
+            emit filename(DataManager::instance()->getstrFileName());
+            m_nFileID ++;
+
+            if (QDir(m_saveVdFolder).exists() == false) {
+                m_saveVdFolder = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation) + QDir::separator() + "Camera";
+            }
+
+            QString outPutPath = QString(m_saveVdFolder + QDir::separator() + DataManager::instance()->getstrFileName());
+            Camera::instance()->setVideoOutPutPath(outPutPath);
+            Camera::instance()->startRecoder();
             emit updateBlockSystem(true);
             setCapStatus(true);
             m_countTimer->stop();
@@ -1254,6 +1440,13 @@ void videowidget::setHorizontalMirror(bool bMirror)
     }
 }
 
+void videowidget::setCapStatus(bool status)
+{
+    m_bActive = status;
+    if (DataManager::instance()->encodeEnv() == GStreamer_Env)
+        m_imgPrcThread->setRecording(status);
+}
+
 void videowidget::setFlash(bool bFlashOn)
 {
     m_flashEnable = bFlashOn;
@@ -1266,6 +1459,7 @@ void videowidget::setMaxRecTime(int hour)
 
 void videowidget::setFilterType(efilterType type)
 {
+    m_filterType = type;
     if (m_imgPrcThread)
         m_imgPrcThread->setFilter(filterPreviewButton::filterName_CUBE(type));
 }
@@ -1316,16 +1510,26 @@ void videowidget::setGridType(GridType type)
 
 void videowidget::onExposureChanged(int exposure)
 {
+    m_exposure = exposure;
     if (m_imgPrcThread)
         m_imgPrcThread->setExposure(exposure);
 }
 
+void videowidget::onFilterDisplayChanged(int bDisplay)
+{
+    if (m_imgPrcThread)
+        m_imgPrcThread->setFilterGroupState(bDisplay);
+}
+
 videowidget::~videowidget()
 {
     m_imgPrcThread->stop();
     m_imgPrcThread->wait();
     delete m_imgPrcThread;
 
+    m_audPrcThread->stop();
+    m_audPrcThread->wait();
+    delete m_audPrcThread;
 #ifndef __mips__
     if (!get_wayland_status()) {
         if (m_openglwidget) {
@@ -1368,5 +1572,8 @@ videowidget::~videowidget()
     delete m_recordingTimer;
     m_recordingTimer = nullptr;
 
+    delete m_videoWriter;
+    m_videoWriter = nullptr;
+
     camUnInit();
 }
