@@ -40,10 +40,13 @@
 
 #include "LPF_V4L2.h"
 #include "majorimageprocessingthread.h"
+#include "audioprocessingthread.h"
 #include "previewopenglwidget.h"
 #include "filterpreviewbutton.h"
 #include "gridline.h"
 
+#include "gstvideowriter.h"
+
 DWIDGET_USE_NAMESPACE
 QT_FORWARD_DECLARE_CLASS(QOpenGLShaderProgram)
 QT_FORWARD_DECLARE_CLASS(QOpenGLTexture)
@@ -173,10 +176,7 @@ public:
     * @brief setCapStatus　设置相机状态
     * @param status 拍照状态
     */
-    void setCapStatus(bool status)
-    {
-        m_bActive = status;
-    }
+    void setCapStatus(bool status);
 
     /**
     * @brief getCapStatus　获取相机录制状态
@@ -270,6 +270,16 @@ public:
      */
     void setGridType(GridType type);
 
+    /**
+    * @brief showNocam　显示没有设备的图片的槽函数
+    */
+    void showNocam();
+
+    /**
+    * @brief showCountDownLabel　显示设备被占用或者拔掉的图片的槽函数
+    */
+    void showCamUsed();
+
 public slots:
     /**
     * @brief onTakePic　拍照事件响应
@@ -318,6 +328,12 @@ public slots:
      */
     void onExposureChanged(int exposure);
 
+    /**
+     * @brief onFilterDisplayChanged 滤镜展开状态
+     * @param bDisplay 是否展示
+     */
+    void onFilterDisplayChanged(int bDisplay);
+
 private slots:
     /**
     * @brief ReceiveMajorImage　处理视频帧 mips、wayland下使用
@@ -353,6 +369,16 @@ private slots:
     */
     void slotGridTypeChanged(int);
 
+    /**
+    * @brief onRecordFrame　向GStreamer写入视频帧数据
+    */
+    void onRecordFrame(uchar* yuv, uint size);
+
+    /**
+    * @brief onRecordAudio　向GStreamer写入音频帧数据
+    */
+    void onRecordAudio(uchar* data, uint size);
+
 private:
     void resizeEvent(QResizeEvent *size) Q_DECL_OVERRIDE;
 
@@ -368,21 +394,16 @@ private:
     */
     void forbidScrollBar(QGraphicsView *view);
 
-    /**
-    * @brief showCountDownLabel　显示设备被占用或者拔掉的图片的槽函数
-    */
-    void showCamUsed();
-
-    /**
-    * @brief showNocam　显示没有设备的图片的槽函数
-    */
-    void showNocam();
-
     /**
     * @brief startTakeVideo　开始录像
     */
     void startTakeVideo();
 
+    /**
+     * @brief startCaptureVideo gstreamer环境下录制视频
+     */
+    void startCaptureVideo();
+
     /**
     * @brief itemPosChange　item位置改变
     */
@@ -403,7 +424,7 @@ private:
 
 public:
     MajorImageProcessingThread *m_imgPrcThread;
-
+    AudioProcessingThread      *m_audPrcThread;
 private:
     bool                       m_bActive;           //是否录制中
     int                        m_nMaxContinuous;    //最大连拍数：0,4,10
@@ -442,6 +463,11 @@ private:
     QGraphicsTextItem          *m_pCamErrItem;      //摄像头异常提示
     bool                       m_flashEnable;       //是否闪光灯
     bool                       m_bPhoto = true;     //相机当前状态，默认为拍照状态
+
+    GstVideoWriter             *m_videoWriter;      //基于GStreamer实现的视频帧数据写入器
+    efilterType                m_filterType;        //当前选择的滤镜名称
+    int                        m_exposure;
+
 };
 
 #endif // VIDEOWIDGET_H
